==> pysswords-0.0.8.3.tar.gz: pysswords-0.0.8.3/setup.py <==
#!/usr/bin/env python
from setuptools import setup, find_packages

requirements_file = "requirements.txt"
requirements = [pkg.strip() for pkg in open(requirements_file).readlines()]

with open("README.md") as f:
    long_description = f.read() + '\n'

__version__ = "0.0.8.3"

setup(
    name='pysswords',
    version=__version__,
    license='License :: OSI Approved :: MIT License',
    description="Manage your login credentials from the terminal painlessly.",
    long_description=long_description,
    author='Marcwebbie',
    author_email='marcwebbie@gmail.com',
    url='https://github.com/marcwebbie/pysswords',
    download_url='https://pypi.python.org/pypi/pysswords',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'pysswords = pysswords.__main__:main',
        ]
    },
    install_requires=requirements,
    tests_require=['mock'],
    test_suite='tests.test',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Environment :: Console',
        'Intended Audience :: End Users/Desktop',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Topic :: Security :: Cryptography',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
)

==> pysswords-0.0.9.tar.gz: pysswords-0.0.9/setup.py <==
#!/usr/bin/env python
from setuptools import setup, find_packages

requirements_file = "requirements.txt"
requirements = [pkg.strip() for pkg in open(requirements_file).readlines()]

with open("README.md") as f:
    long_description = f.read() + '\n'

__version__ = "0.0.9"

setup(
    name='pysswords',
    version=__version__,
    license='License :: OSI Approved :: MIT License',
    description="Manage your login credentials from the terminal painlessly.",
    long_description=long_description,
    author='Marcwebbie',
    author_email='marcwebbie@gmail.com',
    url='https://github.com/marcwebbie/pysswords',
    download_url='https://pypi.python.org/pypi/pysswords',
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'pysswords = pysswords.__main__:main',
        ]
    },
    install_requires=requirements,
    tests_require=['mock'],
    test_suite='tests.test',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Environment :: Console',
        'Intended Audience :: End Users/Desktop',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Topic :: Security :: Cryptography',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
)
